import {
  Controller,
  Get,
  Post,
  Body,
  Patch,
  Param,
  Delete,
  Request,
  HttpStatus,
} from '@nestjs/common';
import { TransactionService } from './transaction.service';
import { DistributeTransactionDto } from './dto/distribute-transaction.dto';
import { OrderTransactionDto } from './dto/order-transaction.dto';
import { UpdateTransactionDto } from './dto/update-transaction.dto';
import { AddSaldoSupplier } from './dto/add-saldo-supplier.dto';

@Controller({
  path: 'transaction',
  version: '1',
})
export class TransactionController {
  constructor(private readonly transactionService: TransactionService) {}

  @Post('distribute')
  create(
    @Body() createTransactionDto: DistributeTransactionDto,
    @Request() req,
  ) {
    return this.transactionService.distributeDeposit(
      createTransactionDto,
      req.user,
    );
  }

  @Post('distribute-admin')
  distributeAdmin(
    @Body() createTransactionDto: DistributeTransactionDto,
    @Request() req,
  ) {
    return {
      data: this.transactionService.distributeFromAdmin(
        createTransactionDto,
        req.user,
      ),
      statusCode: HttpStatus.CREATED,
      message: 'success',
    };
  }

  @Post('add-saldo-supplier')
  async addSaldoSupplier(
    @Body() addSaldoSupplier: AddSaldoSupplier,
    @Request() req,
  ) {
    return {
      data: await this.transactionService.addIRSWallet(
        addSaldoSupplier,
        req.user,
      ),
      statusCode: HttpStatus.CREATED,
      message: 'success',
    };
  }

  @Post('order')
  orderTransaction(
    @Body() orderTransactionDto: OrderTransactionDto,
    @Request() req,
  ) {
    return this.transactionService.orderTransaction(
      orderTransactionDto,
      req.user,
    );
  }
}
